@@ -469,18 +469,15 @@ class ProjectsMixin(object):
         setting the corresponding keyword argument to `False` or `True`
         respectively.
 
-        This method returns a requests. Response object.
-        See http://docs.python-requests.org/en/master/api/#requests.Response for  # noqa
-        more details.
-
         The content of the response contains an export_id which can be then used
-        as a parameter to get_project_export method to retrieve the zip archive
+        as a parameter to :func:`get_project_export` method to retrieve the zip
+        archive.
 
         :param project_id: Project identifier.
         :param export_app_nav_bar: Boolean. Whether to include the
             app & nav bar. Defaults to `True`.
         :param export_default_sort: Boolean. Whether to include the
-        default_sort. Defaults to `True`.
+            default_sort. Defaults to `True`.
         :param export_dashboards: Boolean. Whether to include the dashboards,
             defaults to `True`.
         :param export_dashboard_widgets: Boolean. Whether to include the
@@ -533,6 +530,8 @@ class ProjectsMixin(object):
         :param export_items_config: Dict. Containing the query parameters that
             can be used to filter down the exported items. Currently only
             `query` and `count` parameters are supported.
+        :return: Returns a dictionary containing the API response data and
+            headers.
 
         Example::
 
@@ -540,7 +539,7 @@ class ProjectsMixin(object):
                     'gd9eIipOQ-KobU0SwJ8VcQ', {'dashboards': True})
 
 
-            For saving the archive, refer to get_project_export method
+        For saving the archive, refer to :func:`get_project_export` method.
         """
 
         url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/export" % {
@@ -704,10 +703,6 @@ class ProjectsMixin(object):
         By default all entities are imported. You can skip some by setting the
         corresponding keyword argument to `False` or `True` respectively.
 
-        This method returns a requests.Response object.
-        See http://docs.python-requests.org/en/master/api/#requests.Response for
-        more details.
-
         :param project_id: Project identifier.
         :param project_archive: Path to project archive.
         :param import_app_nav_bar: Boolean. Whether to include the
@@ -765,6 +760,8 @@ class ProjectsMixin(object):
             also.
         :param import_guide_file: Boolean. Whether to include the project guide file,
             defaults to `True`.
+        :return: Returns a dictionary containing the API response data and
+            headers.
 
         Example::
 
